@@ -56,11 +56,15 @@ def scandata(dimidx,axisref,SEL,data,deffunc,SELout,dataout):
             scandata(dimidx + 1,axisref,SEL,data,deffunc,SELout,dataout)
         else:
             dtemp= deffunc(data[arraysel(SEL,data.shape)])
-            if type(dtemp).__name__ == 'list':
+            if ((type(dtemp).__name__ == 'list') or (type(dtemp).__name__ == 'tuple')):
                 dataout[arraysel(SELout,dataout.shape)] = dtemp[0]
             else:
                 dataout[arraysel(SELout,dataout.shape)] = dtemp
 
+
+
+
+
         axidx = axidx + 1
 
 # reduce dimension of a multidimensional matrix
@@ -77,6 +81,9 @@ def reddim(data,indices,el = 0):
             SEL[dim] = range(size(data,axis=dim))
     return data[arraysel(SEL,shape(data))]
 
+# also called by multifunc, but may be used for other things also. 
+# ----Isn't this just doing what's done at the inner scandata loop? maybe it has to be merged with that to have one
+# single logic...---
 def sizeout(data,axisref,deffunc):
     SEL = list(repeat(None,len(shape(data))))
     sizeout = list(repeat(None,len(shape(data))))
@@ -87,8 +94,6 @@ def sizeout(data,axisref,deffunc):
         else:
             SEL[dim] = [0] 
             sizeout[dim] = size(data,axis=dim)
-    # print(SEL)
-    # print(data.shape)
 
     # the first item in this list contains dummy data which will not be used; 
     # the other items potentially contain the output coordinates if available
@@ -98,7 +103,7 @@ def sizeout(data,axisref,deffunc):
         if (axisref[dim] == True):
             # if list, get the output data size which is given by the first item in the list
             # if not list (no output coordinates given), just get the size of the data
-            if type(dummydataout).__name__ == 'list':
+            if ((type(dummydataout).__name__ == 'list') or (type(dummydataout).__name__ == 'tuple')):
                 sizeout[dim] = size(dummydataout[0],axis=dimout)
             else:
                 sizeout[dim] = size(dummydataout,axis=dimout)
@@ -108,11 +113,14 @@ def sizeout(data,axisref,deffunc):
     #                        axisref, \
     #                        lambda data: deffunc(data) )
     # get the output coordinates of the processed dimensions and save it as a seperate list
-    if type(dummydataout).__name__ == 'list':
-        if type(dummydataout[1]).__name__ != 'list': # multiple coordinate set stored as a list
-            outcoords = list(dummydataout[1])
-        else:
+    if ((type(dummydataout).__name__ == 'list') or (type(dummydataout).__name__ == 'tuple')):
+        if (type(dummydataout[1]).__name__ == 'list' ): # multiple coordinate set stored as a list
             outcoords = dummydataout[1] 
+        else:
+            if (dummydataout[1] != None):
+                outcoords = list(dummydataout[1])
+            else:
+                outcoords = None
     else:
         outcoords = None # function doesn't have output coordinates available
 
