@@ -57,10 +57,13 @@ def datacosel(indata, cocosel = None, coords = None, outcoords = None, \
     # would be more elegant if we could simply do cosel = cosel[cosel!=None], but None inside [] does strange things
     if (crop == True):
         tempcosel = []
-        for ecosel in cosel:
+        tempoutcoords = []
+        for icosel,ecosel in enumerate(cosel):
             if (ecosel != None):
                 tempcosel.append(ecosel)
+                tempoutcoords.append(outcoords[icosel])
         cocosel = array(tempcosel)
+        outcoords = array(outcoords)
 
     dataout = tile(None,len(cocosel))
     #dataout = indata[cosel[cosel!=None]]
@@ -71,7 +74,7 @@ def datacosel(indata, cocosel = None, coords = None, outcoords = None, \
             dataout[iel] = indata[el]
         else:
             dataout[iel] = None
-    return dataout, outcoords
+    return list([dataout, outcoords])
 
 
 # aim: build an array (boolean) selection from indices of any dimension
