@@ -37,14 +37,14 @@ def avgcycle(data, timeco = None, timewarp = None, cclose=False):
     
             # if some data could not be selected, a nan will be produced
             # in cosel, crop is left to False, because we want to discover whenever data is not available
-            tdatacosel = datacosel(data,cocosel = tempcosel)
+            tdatacosel = datacosel(data,cocosel = tempcosel)[0]
 
             # we don't want to end up with an error if None is met: we just want a 'nan' from the mean.
             for edata in tdatacosel:
                 if (edata == None):
                     edata = nan
 
-            dataout.append(mean(datacosel(data,cocosel = tempcosel)))
+            dataout.append(mean(datacosel(data,cocosel = tempcosel)[0]))
             timecoout.append(timeco[idata])
             #dataout.append(mean(scisel(data,timeco,tempco2) )
     
